@@ -42,8 +42,8 @@ class UMIRobotMainWindow(QMainWindow):
         self.umi_robot_shared_memory_receiver = umi_robot_shared_memory_receiver
         self.is_open = False
         self.qd = [0, 0, 0, 0, 0, 0]
-        self.q_min = -60
-        self.q_max = 60
+        self.q_min = -90
+        self.q_max = 90
 
         self.pot_min = [None] * 6
         self.pot_max = [None] * 6
@@ -221,7 +221,7 @@ class UMIRobotMainWindow(QMainWindow):
                 if self._are_potentiometers_calibrated():
                     for i in range(0, 6):
                         self.potentiometer_qd[i] = int(
-                            float(potentiometer_values[i] / (self.pot_max[i] - self.pot_min[i])) * 120.0) - 60
+                            float(potentiometer_values[i] / (self.pot_max[i] - self.pot_min[i])) * 180.0) - 90
 
                 self.ui.lineedit_pot_0.setText(str(self.potentiometer_qd[0]))
                 self.ui.lineedit_pot_1.setText(str(self.potentiometer_qd[1]))
@@ -326,9 +326,9 @@ class UMIRobotMainWindow(QMainWindow):
             self.log("Warning::No port selected.")
 
     def _button_refresh_port_clicked_callback(self):
-        import serial.tools.list_ports
         self.ui.combobox_port.clear()
         if _platform == 'win32':
+            import serial.tools.list_ports
             ports_list = serial.tools.list_ports.comports()
             for port in ports_list:
                 self.ui.combobox_port.addItem(str(port.name))
@@ -338,7 +338,7 @@ class UMIRobotMainWindow(QMainWindow):
             # https://stackoverflow.com/questions/22467683/listing-serial-ports-in-mac-os-x-and-python-3
             ports_list = glob.glob('/dev/tty.*')
             for port in ports_list:
-                self.ui.combobox_port.addItem(port)
+                self.ui.combobox_port.addItem(str(port))
         if len(ports_list) == 0:
             self.log("Warning::Updated ports but no ports available.")
         else:
